// Processing 3.0 Receiver for GyrOSC Phone Sensor Data
// By Golan Levin, March 2017

// http://www.bitshapesoftware.com/instruments/gyrosc/
// GyrOSC is a utility that sends your phone's sensor 
// data over your local wireless network over OSC.
// Control your live audio or video application with your 
// device's built-in gyroscope, accelerometer, and compass.

import oscP5.*;
OscP5 oscP5;

PVector gyroVals  = new PVector();
PVector accelVals = new PVector();
PVector magVals   = new PVector();
PVector gpsVals   = new PVector();
PVector gravVals  = new PVector();
float compassHeading; 

//-----------------------------------
void setup() {
  size(640, 640, P3D);
  
  oscP5 = new OscP5(this, 9999);
  oscP5.plug(this, "gyroDataReceived",    "/gyrosc/gyro");
  oscP5.plug(this, "accelDataReceived",   "/gyrosc/accel");
  oscP5.plug(this, "magDataReceived",     "/gyrosc/mag");
  oscP5.plug(this, "gpsDataReceived",     "/gyrosc/gps");
  oscP5.plug(this, "gravDataReceived",    "/gyrosc/grav");
  oscP5.plug(this, "compassDataReceived", "/gyrosc/comp");
}

//-----------------------------------
void draw() { 
  background(0); 
   
  fill(255,200,200, 100); 
  stroke(255);
  strokeWeight(2); 
  pushMatrix(); 
  translate(width/2.0, height/2.0); 
  scale(2.0); 
  rotateZ(0-gyroVals.z); 
  rotateX(gyroVals.x); 
  rotateY(gyroVals.y); 
  box(58.6, 123.8, 7.6); // Dimensions of my iPhone
  popMatrix(); 
  
  //----------------------
  float ty = 0; 
  float dy = 20; 
  fill(255);
  text("GyrOSC Receiver for Processing", 10, ty+=dy); 
  
  text("Pitch: " + nf(degrees(gyroVals.x), 1,4), 10, ty+=dy); 
  text("Roll: "  + nf(degrees(gyroVals.y), 1,4), 10, ty+=dy);
  text("Yaw: "   + nf(degrees(gyroVals.z), 1,4), 10, ty+=dy); 
  
  text("Accel X: " + nf(accelVals.x, 1,6), 10, ty+=dy); 
  text("Accel Y: " + nf(accelVals.y, 1,6), 10, ty+=dy);
  text("Accel Z: " + nf(accelVals.z, 1,6), 10, ty+=dy); 
  
  text("GPS Lat: " + nf(gpsVals.x, 1,6), 10, ty+=dy); 
  text("GPS Lon: " + nf(gpsVals.y, 1,6), 10, ty+=dy);
  text("GPS Alt: " + nf(gpsVals.z, 1,6), 10, ty+=dy); 
  
  text("MagField X: " + nf(magVals.x, 1,2), 10, ty+=dy); 
  text("MagField Y: " + nf(magVals.y, 1,2), 10, ty+=dy);
  text("MagField Z: " + nf(magVals.z, 1,2), 10, ty+=dy); 
  
  text("Gravity X: " + nf(gravVals.x, 1,4), 10, ty+=dy); 
  text("Gravity Y: " + nf(gravVals.y, 1,4), 10, ty+=dy);
  text("Gravity Z: " + nf(gravVals.z, 1,4), 10, ty+=dy); 
  
  text("Heading: " + compassHeading, 10, ty+=dy); 
}


//-----------------------------------
public void gyroDataReceived(float pitch, float roll, float yaw) {
  gyroVals.set(pitch, roll, yaw); 
}

public void accelDataReceived(float x, float y, float z) {
  accelVals.set(x,y,z); 
}

public void magDataReceived(float x, float y, float z) {
  magVals.set(x,y,z); 
}

public void gpsDataReceived(float[] gps) {
  float lat = gps[0]; 
  float lon = gps[1]; 
  float alt = gps[2]; 
  gpsVals.set(lat, lon, alt); 
}

public void gravDataReceived(float x, float y, float z) {
  gravVals.set(x,y,z); 
}

public void compassDataReceived(float heading) {
  compassHeading = heading;
}

//-----------------------------------
// all other OSC messages end up here
void oscEvent(OscMessage m) {
  if (m.isPlugged() == false) {
    // println("UNPLUGGED: " + m);
  }
}